@@ -15,7 +15,8 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2006, 2007, 2009, 2010, 2011, 2012, 2013, 2014
+ * Copyright 2017, 2022, 2023 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2006-2007, 2009-2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -35,11 +36,13 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
+ *
+ * SPDX-License-Identifier: MIT
  */
 
 #include <config.h>
 #ifdef HAVE_KRB5
-# include <portable/krb5.h>
+#    include <portable/krb5.h>
 #endif
 #include <portable/system.h>
 
@@ -56,7 +59,7 @@
  * to handle the possible patterns for kinit commands as an array.
  */
 #if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 2) || defined(__clang__)
-# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#    pragma GCC diagnostic ignored "-Wformat-nonliteral"
 #endif
 
 
@@ -155,17 +158,16 @@ kerberos_kinit(void)
 static void
 kerberos_kinit(void)
 {
-    static const char * const format[] = {
+    static const char *const format[] = {
         "kinit --no-afslog -k -t %s %s >/dev/null 2>&1 </dev/null",
         "kinit -k -t %s %s >/dev/null 2>&1 </dev/null",
         "kinit -t %s %s >/dev/null 2>&1 </dev/null",
-        "kinit -k -K %s %s >/dev/null 2>&1 </dev/null"
-    };
+        "kinit -k -K %s %s >/dev/null 2>&1 </dev/null"};
     FILE *file;
     char *path;
     char principal[BUFSIZ], *command;
     size_t i;
-    int status;
+    int status = 0;
 
     /* Read the principal corresponding to the keytab. */
     path = test_file_path("config/principal");
@@ -209,9 +211,11 @@ kerberos_kinit(void)
  * process so that test programs that fork don't remove the ticket cache still
  * used by the main program.
  */
-static void
-kerberos_free(void)
+void
+kerberos_free(struct kerberos_config *config_arg)
 {
+    if (config_arg != config)
+        bail("invalid argument to kerberos_free");
     test_tmpdir_free(tmpdir_ticket);
     tmpdir_ticket = NULL;
     if (config != NULL) {
@@ -223,7 +227,14 @@ kerberos_free(void)
         free(config->password);
         free(config->pkinit_principal);
         free(config->pkinit_cert);
-        free(config);
+
+        /*
+         * Free config_arg rather than config, since otherwise cppcheck thinks
+         * that config_arg could be const, which while technically true would
+         * look very weird since config_arg is invalidated by calling this
+         * function.
+         */
+        free(config_arg);
         config = NULL;
     }
     if (krb5ccname != NULL) {
@@ -255,7 +266,7 @@ kerberos_cleanup(void)
         unlink(path);
         free(path);
     }
-    kerberos_free();
+    kerberos_free(config);
 }
 
 
@@ -271,7 +282,7 @@ kerberos_cleanup_handler(int success UNUSED, int primary)
     if (primary)
         kerberos_cleanup();
     else
-        kerberos_free();
+        kerberos_free(config);
 }
 
 
@@ -361,7 +372,7 @@ kerberos_setup(enum kerberos_needs needs)
     path = test_file_path("config/pkinit-principal");
     if (path != NULL)
         file = fopen(path, "r");
-    if (file != NULL) {
+    if (path != NULL && file != NULL) {
         if (fgets(buffer, sizeof(buffer), file) == NULL)
             bail("cannot read %s", path);
         if (buffer[strlen(buffer) - 1] != '\n')
@@ -457,17 +468,19 @@ kerberos_generate_conf(const char *realm)
 
 
 /*
- * Report a Kerberos error and bail out.
+ * Report a Kerberos error and bail out.  Takes a long instead of a
+ * krb5_error_code because it can also handle a kadm5_ret_t (which may be a
+ * different size).
  */
 void
-bail_krb5(krb5_context ctx, krb5_error_code code, const char *format, ...)
+bail_krb5(krb5_context ctx, long code, const char *format, ...)
 {
     const char *k5_msg = NULL;
     char *message;
     va_list args;
 
     if (ctx != NULL)
-        k5_msg = krb5_get_error_message(ctx, code);
+        k5_msg = krb5_get_error_message(ctx, (krb5_error_code) code);
     va_start(args, format);
     bvasprintf(&message, format, args);
     va_end(args);
@@ -479,17 +492,19 @@ bail_krb5(krb5_context ctx, krb5_error_code code, const char *format, ...)
 
 
 /*
- * Report a Kerberos error as a diagnostic to stderr.
+ * Report a Kerberos error as a diagnostic to stderr.  Takes a long instead of
+ * a krb5_error_code because it can also handle a kadm5_ret_t (which may be a
+ * different size).
  */
 void
-diag_krb5(krb5_context ctx, krb5_error_code code, const char *format, ...)
+diag_krb5(krb5_context ctx, long code, const char *format, ...)
 {
     const char *k5_msg = NULL;
     char *message;
     va_list args;
 
     if (ctx != NULL)
-        k5_msg = krb5_get_error_message(ctx, code);
+        k5_msg = krb5_get_error_message(ctx, (krb5_error_code) code);
     va_start(args, format);
     bvasprintf(&message, format, args);
     va_end(args);
@@ -524,14 +539,12 @@ kerberos_keytab_principal(krb5_context ctx, const char *path)
     if (status != 0)
         bail_krb5(ctx, status, "error reading %s", path);
     status = krb5_kt_next_entry(ctx, keytab, &entry, &cursor);
-    if (status == 0) {
-        status = krb5_copy_principal(ctx, entry.principal, &princ);
-        if (status != 0)
-            bail_krb5(ctx, status, "error copying principal from %s", path);
-        krb5_kt_free_entry(ctx, &entry);
-    }
     if (status != 0)
         bail("no principal found in keytab file %s", path);
+    status = krb5_copy_principal(ctx, entry.principal, &princ);
+    if (status != 0)
+        bail_krb5(ctx, status, "error copying principal from %s", path);
+    krb5_kt_free_entry(ctx, &entry);
     krb5_kt_end_seq_get(ctx, keytab, &cursor);
     krb5_kt_close(ctx, keytab);
     return princ;
