@@ -5,7 +5,8 @@
  * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
- * Copyright 2006, 2007, 2009, 2011, 2012, 2013, 2014
+ * Copyright 2017, 2020, 2022 Russ Allbery <eagle@eyrie.org>
+ * Copyright 2006-2007, 2009, 2011-2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -25,6 +26,8 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
+ *
+ * SPDX-License-Identifier: MIT
  */
 
 #ifndef TAP_KERBEROS_H
@@ -34,20 +37,20 @@
 #include <tests/tap/macros.h>
 
 #ifdef HAVE_KRB5
-# include <portable/krb5.h>
+#    include <portable/krb5.h>
 #endif
 
 /* Holds the information parsed from the Kerberos test configuration. */
 struct kerberos_config {
-    char *keytab;               /* Path to the keytab. */
-    char *principal;            /* Principal whose keys are in the keytab. */
-    char *cache;                /* Path to the Kerberos ticket cache. */
-    char *userprinc;            /* The fully-qualified principal. */
-    char *username;             /* The local (non-realm) part of principal. */
-    char *realm;                /* The realm part of the principal. */
-    char *password;             /* The password. */
-    char *pkinit_principal;     /* Principal for PKINIT authentication. */
-    char *pkinit_cert;          /* Path to certificates for PKINIT. */
+    char *keytab;           /* Path to the keytab. */
+    char *principal;        /* Principal whose keys are in the keytab. */
+    char *cache;            /* Path to the Kerberos ticket cache. */
+    char *userprinc;        /* The fully-qualified principal. */
+    char *username;         /* The local (non-realm) part of principal. */
+    char *realm;            /* The realm part of the principal. */
+    char *password;         /* The password. */
+    char *pkinit_principal; /* Principal for PKINIT authentication. */
+    char *pkinit_cert;      /* Path to certificates for PKINIT. */
 };
 
 /*
@@ -56,11 +59,13 @@ struct kerberos_config {
  * tests require both keytab and password, but PKINIT is not required.
  */
 enum kerberos_needs {
+    /* clang-format off */
     TAP_KRB_NEEDS_NONE     = 0x00,
     TAP_KRB_NEEDS_KEYTAB   = 0x01,
     TAP_KRB_NEEDS_PASSWORD = 0x02,
     TAP_KRB_NEEDS_BOTH     = 0x01 | 0x02,
     TAP_KRB_NEEDS_PKINIT   = 0x04
+    /* clang-format on */
 };
 
 BEGIN_DECLS
@@ -71,6 +76,8 @@ BEGIN_DECLS
  * them in a Kerberos ticket cache, sets KRB5_KTNAME and KRB5CCNAME.  It also
  * loads the principal and password from config/password, if it exists, and
  * stores the principal, password, username, and realm in the returned struct.
+ * The returned struct is also saved statically to allow for easier cleanup
+ * and thus cleaner valgrind output in tests.
  *
  * If there is no config/keytab file, KRB5_KTNAME and KRB5CCNAME won't be set
  * and the keytab field will be NULL.  If there is no config/password file,
@@ -82,9 +89,14 @@ BEGIN_DECLS
  * however, be called directly if for some reason the caller needs to delete
  * the Kerberos environment again.  However, normally the caller can just call
  * kerberos_setup again.
+ *
+ * kerberos_free is an alternate way of calling kerberos_cleanup that
+ * satisfies the __malloc__ annotation requirements.  There is normally no
+ * need to call it.
  */
+void kerberos_free(struct kerberos_config *);
 struct kerberos_config *kerberos_setup(enum kerberos_needs)
-    __attribute__((__malloc__));
+    __attribute__((__malloc__(kerberos_free)));
 void kerberos_cleanup(void);
 
 /*
@@ -103,15 +115,15 @@ void kerberos_cleanup(void);
 void kerberos_generate_conf(const char *realm);
 void kerberos_cleanup_conf(void);
 
-/* Thes interfaces are only available with native Kerberos support. */
+/* These interfaces are only available with native Kerberos support. */
 #ifdef HAVE_KRB5
 
 /* Bail out with an error, appending the Kerberos error message. */
-void bail_krb5(krb5_context, krb5_error_code, const char *format, ...)
+void bail_krb5(krb5_context, long, const char *format, ...)
     __attribute__((__noreturn__, __nonnull__(3), __format__(printf, 3, 4)));
 
 /* Report a diagnostic with Kerberos error to stderr prefixed with #. */
-void diag_krb5(krb5_context, krb5_error_code, const char *format, ...)
+void diag_krb5(krb5_context, long, const char *format, ...)
     __attribute__((__nonnull__(3), __format__(printf, 3, 4)));
 
 /*
